// MainFrm.cpp : implementation of the CMainFrame class
//

#include "stdafx.h"
#include "MultiScreen.h"

#include "MainFrm.h"
#include "Doc.h"
#include "Doc2.h"
#include "View1.h"
#include "View5.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif


// CMainFrame

IMPLEMENT_DYNCREATE(CMainFrame, CFrameWnd)

BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
	ON_WM_CREATE()
	ON_COMMAND(IDM_VIEW1, &CMainFrame::OnView1)
	ON_COMMAND(IDM_VIEW5, &CMainFrame::OnView5)
	ON_UPDATE_COMMAND_UI(IDM_VIEW1, &CMainFrame::OnUpdateView1)
	ON_UPDATE_COMMAND_UI(IDM_VIEW5, &CMainFrame::OnUpdateView5)
END_MESSAGE_MAP()

static UINT indicators[] =
{
	ID_SEPARATOR,           // status line indicator
	ID_INDICATOR_CAPS,
	ID_INDICATOR_NUM,
	ID_INDICATOR_SCRL,
};


// CMainFrame construction/destruction

CMainFrame::CMainFrame()
{
	// TODO: add member initialization code here
}

CMainFrame::~CMainFrame()
{
}


int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
	if (CFrameWnd::OnCreate(lpCreateStruct) == -1)
		return -1;
	
	if (!m_wndToolBar.CreateEx(this, TBSTYLE_FLAT, WS_CHILD | WS_VISIBLE | CBRS_TOP
		| CBRS_GRIPPER | CBRS_TOOLTIPS | CBRS_FLYBY | CBRS_SIZE_DYNAMIC) ||
		!m_wndToolBar.LoadToolBar(IDR_MAINFRAME))
	{
		TRACE0("Failed to create toolbar\n");
		return -1;      // fail to create
	}

	if (!m_wndStatusBar.Create(this) ||
		!m_wndStatusBar.SetIndicators(indicators,
		  sizeof(indicators)/sizeof(UINT)))
	{
		TRACE0("Failed to create status bar\n");
		return -1;      // fail to create
	}

	// TODO: Delete these three lines if you don't want the toolbar to be dockable
	m_wndToolBar.EnableDocking(CBRS_ALIGN_ANY);
	EnableDocking(CBRS_ALIGN_ANY);
	DockControlBar(&m_wndToolBar);

	return 0;
}

BOOL CMainFrame::PreCreateWindow(CREATESTRUCT& cs)
{
	if( !CFrameWnd::PreCreateWindow(cs) )
		return FALSE;
	// TODO: Modify the Window class or styles here by modifying
	//  the CREATESTRUCT cs

	return TRUE;
}


// CMainFrame diagnostics

#ifdef _DEBUG
void CMainFrame::AssertValid() const
{
	CFrameWnd::AssertValid();
}

void CMainFrame::Dump(CDumpContext& dc) const
{
	CFrameWnd::Dump(dc);
}

#endif //_DEBUG


/////////////////////////////////////////////////////////////////////////////
// CMainFrame message handlers

//---------------------------------------------------------------
//	Desc:	Switches out the current view with a new view and eliminate the old view
//	Params:	A paramater to indicate what view to switch in can be anything you wish
//	returns:
//---------------------------------------------------------------

void CMainFrame::SwitchToView(int nView)
{
	switch (nView)
	{
	case 1:
		ReplaceView(RUNTIME_CLASS(CView1));
		break;
	case 5:
		ReplaceView(RUNTIME_CLASS(CView5));
		break;
	}

#if 0 // Removing all the desperate stuff
  CView* pOldActiveView = GetActiveView();	// save old view
  CView* pNewActiveView;

  CDocument * pOldActiveDocument;			// ?? how to use these appropriately
  CRichEditDoc * pNewActiveDocument;		// to match the views up with the documents

  CDocument* pDoc = GetActiveDocument();



  switch(nView)
  {
	case 1:
	  pNewActiveView = (CView*)new CView1;
	break;
	case 5:
	  pNewActiveView = (CView*)new CView5;
	break;
  }

  pNewActiveView->Create(NULL, NULL, AFX_WS_DEFAULT_VIEW,
	      rectDefault, this, AFX_IDW_PANE_FIRST, NULL);

  // Show the newly active view and hide the inactive view.
  pNewActiveView->ShowWindow(SW_SHOW);  // show the new window
  pOldActiveView->ShowWindow(SW_HIDE);  // hide the old

  // Connect the newly active view to the document, and
  // disconnect the inactive view.
  pDoc->AddView(pNewActiveView);
  pDoc->RemoveView(pOldActiveView);

  SetActiveView(pNewActiveView);	// change the active view
  pNewActiveView->OnInitialUpdate();	  
  RecalcLayout();			 // adjust frame
  delete pOldActiveView;		 // delete old view
#endif
}// SwitchToView(int nView)


/* The cure found here: http://asg.unige.ch/Past/fuentes/Mfc/HowTo_13.html

How To Switch between different Views in a SDI application
This answer was posted by William Dempsey in the Microsoft Foundation Classes mailing list.

Add this function to your CMainFrm class in an SDI app, then call it like this (wherever you feel the urge):


ReplaceView(RUNTIME_CLASS(CSomeClassYouWantToSwitchTo));

*/

BOOL CMainFrame::ReplaceView(CRuntimeClass * pViewClass)
{
    CCreateContext context;
    BOOL           bSetActive;

    ASSERT(!GetActiveView()->IsKindOf(pViewClass));

    // Get pointer to CDocument object so that it can be used in the creation
    // process of the new view

    CDocument * pDoc = ((CView *)GetActiveView())->GetDocument();
    CView * pActiveView = GetActiveView();

    if (pActiveView == NULL || pActiveView == GetActiveView())
        bSetActive = TRUE;
    else
        bSetActive = FALSE;

    // Set flag so that document will not be deleted when view is destroyed
    pDoc->m_bAutoDelete = FALSE;

    // Delete existing view
    ((CView *) GetActiveView())->DestroyWindow();

    // Get flag back to default
    pDoc->m_bAutoDelete = TRUE;

    // Create new view
    context.m_pNewViewClass   = pViewClass;
    context.m_pCurrentDoc     = pDoc;
    context.m_pNewDocTemplate = NULL;
    context.m_pLastView       = NULL;
    context.m_pCurrentFrame   = NULL;

    CView *pNewView = (CView*)CreateView(&context);

    if (bSetActive == TRUE)
        SetActiveView(pNewView);

    GetActiveView()->OnInitialUpdate();
    RecalcLayout();
    GetActiveView()->SendMessage(WM_PAINT);

    return TRUE;
}

void CMainFrame::OnView1()
{
	 SwitchToView(1);
}

void CMainFrame::OnView5()
{
	 SwitchToView(5);
}

void CMainFrame::OnUpdateView1(CCmdUI *pCmdUI)
{
	pCmdUI->Enable(GetActiveView()->GetRuntimeClass()!=RUNTIME_CLASS(CView1));
}

void CMainFrame::OnUpdateView5(CCmdUI *pCmdUI)
{
	pCmdUI->Enable(GetActiveView()->GetRuntimeClass()!=RUNTIME_CLASS(CView5));
}
